@@ -24,7 +24,7 @@ fn main() {
             Some(s) => s,
             None => {
                 println!(
-                    "Unknown strategy {} -- try random, minimize, maximize, monte, or simple.",
+                    "Unknown strategy {} -- try random, constrain, corners, minimize, maximize, monte, or simple.",
                     strategy
                 );
                 return;
@@ -81,7 +81,12 @@ fn main() {
         } else {
             print!("Desdemona...");
             std::io::stdout().flush().unwrap();
-            // opponent (light) plays a random valid move.
+
+            // insert a small delay so it's clear that the computer has played, otherwise
+            // it appears instantaneously.
+            std::thread::sleep(std::time::Duration::from_millis(1000));
+
+            // opponent (light) plays a valid move.
             match strategy.next_play(&game) {
                 Some(vm) => game.play(vm),
                 None => game.pass(),
@@ -139,9 +144,10 @@ fn get_args() -> ArgMatches<'static> {
     App::new("desdemona")
         .version("0.1")
         .author("Peat Bakke <peat@peat.org>")
-        .about("Would you like to play a game?")
+        .long_about(
+            "Would you like to play a game? Available opponent strategies are:\nconstrain, corners, maximize, minimize, monte, random, and simple")
         .args_from_usage(
-            "-s, --strategy=[STRATEGY]       'Determine the computer's strategy: minimize, maximize, random, simple, monte'"
+            "-s, --strategy=[STRATEGY]       'Determine the computer's strategy'"
         )
         .get_matches()
 }
