@@ -1,7 +1,7 @@
+use crate::{Board, Disc, Position};
 use std::fmt::*;
 
-use crate::{Board, Disc, Position};
-
+/// Represents individual plays within the transcript of a game
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub enum Play {
     Move(Position),
@@ -17,18 +17,28 @@ impl Display for Play {
     }
 }
 
+/// Represents the current state of a game in progress. The board positions are indexed from 0 to 63.
+/// See [Board] for more details on how this works.
 #[derive(Debug, Default, Clone, PartialEq, Eq)]
 pub struct Game {
+    /// Which player is currently playing
     pub turn: Disc,
+    /// The score of the dark player
     pub dark: usize,
+    /// The score of the light player
     pub light: usize,
+    /// The number of empty positions on the board
     pub empty: usize,
+    /// The game board
     pub board: Board,
+    /// The transcript of the game played so far
     pub transcript: Vec<Play>,
+    /// Whether or not the game is complete
     pub is_complete: bool,
 }
 
 impl Game {
+    /// Returns a new game, with the four initial discs placed, and turn set to dark
     pub fn new() -> Self {
         let turn = Disc::Dark;
         let board = Board::new();
@@ -46,6 +56,7 @@ impl Game {
         }
     }
 
+    /// Replays a game from a transcript, returning `None` if there's an error.
     pub fn from_transcript(transcript: &[Play]) -> Option<Self> {
         let mut game = Game::new();
         for p in transcript {
@@ -60,7 +71,7 @@ impl Game {
         Some(game)
     }
 
-    /// Determines if a position is a valid move for the current player.
+    /// Determines if a position is a valid move for the current player. Returns the index if so.
     pub fn validate_move(&self, player: Disc, index: usize) -> Option<usize> {
         if self.can_move(player, index) {
             return Some(index);
@@ -69,126 +80,15 @@ impl Game {
         None
     }
 
-    /// Finds all of the valid moves for the current player.
-    #[allow(clippy::manual_flatten)]
-    pub fn valid_moves(&self, player: Disc) -> Vec<usize> {
-        // Note: this could be implemented with map/flatten/collect,
-        // however it's considerably slower than allocating up front.
-        let mut raw_moves: Vec<usize> = Vec::with_capacity(64);
-        for p in self.board.positions_of(None) {
-            if self.can_move(player, p.into()) {
-                raw_moves.push(p.into())
-            }
-        }
-
-        raw_moves.sort_unstable();
-        raw_moves.dedup();
-
-        raw_moves
+    /// Returns an `Iterator` with all of the valid moves for the current player.
+    pub fn valid_moves(&self, player: Disc) -> impl Iterator<Item = usize> + '_ {
+        self.board
+            .indexes_of(None)
+            .filter(move |index| self.can_move(player, *index))
     }
 
-    // a result of None indicates it's not a valid move
-    pub fn play(&mut self, position: usize) {
-        // find the flips for playing that position
-        let mut flips = self.flips_for(position).unwrap();
-
-        // save this for scoring updates
-        let changed = flips.len();
-
-        // add the position to discs to set
-        flips.push(position);
-
-        // iterate through the flips and set those discs to the current player
-        for p in flips.iter() {
-            self.board.set(*p, self.turn);
-        }
-
-        // save the played position to the transcript
-        self.transcript.push(Play::Move(Position::new(position)));
-
-        // update the score and completeness
-        if self.turn == Disc::Dark {
-            self.dark += changed + 1; // include the newly placed piece
-            self.light -= changed; // all of the flipped discs
-        } else {
-            self.light += changed + 1; // include the newly placed piece
-            self.dark -= changed; // all of the flipped discs
-        }
-
-        self.empty -= 1;
-
-        if self.empty == 0 {
-            self.is_complete = true;
-        }
-
-        // update the turn
-        self.turn = self.turn.opposite();
-    }
-
-    pub fn pass(&mut self) {
-        // if the last (opponent) play was also a pass, then the game is over.
-        if self.transcript.last() == Some(&Play::Pass) {
-            self.is_complete = true;
-        } else {
-            // otherwise, mark the pass and move on to the other player!
-            self.transcript.push(Play::Pass);
-            self.turn = self.turn.opposite();
-        }
-    }
-
-    fn validate_completion(&mut self) {
-        // if there are no more valid moves for either player, then the game is complete.
-        self.is_complete =
-            self.valid_moves(Disc::Dark).is_empty() && self.valid_moves(Disc::Light).is_empty()
-    }
-
-    pub fn can_move(&self, player: Disc, index: usize) -> bool {
-        // basic check ... occupied?
-        if self.board.get(index).is_some() {
-            return false;
-        }
-
-        for line in self.board.lines_for(index) {
-            if self.move_from_empty(player, line).is_some() {
-                return true;
-            }
-        }
-
-        false
-    }
-
-    fn move_from_empty(&self, player: Disc, indexes: &[usize]) -> Option<usize> {
-        let mut line_started = false;
-
-        for idx in indexes {
-            // ignore the first position; it's not a target, it's where we'll be placing the piece!
-            if idx == indexes.first()? {
-                continue;
-            }
-
-            // no disc? return.
-            let disc = self.board.get(*idx)?;
-
-            // possible target disc to flip!
-            if disc == player.opposite() {
-                line_started = true;
-                continue;
-            }
-
-            // we've found our own color -- if we have targets, it's a valid move!
-            if disc == player {
-                if !line_started {
-                    return None;
-                }
-
-                return indexes.first().cloned();
-            }
-        }
-
-        None
-    }
-
-    pub fn flips_for(&self, index: usize) -> Option<Vec<usize>> {
+    /// Returns the position of the discs that _would_ be flipped by playing at a given position.
+    pub fn flips_for(&self, index: usize) -> Vec<usize> {
         let player = self.turn;
         let opposition = self.turn.opposite();
 
@@ -233,11 +133,110 @@ impl Game {
             }
         }
 
-        if flips.is_empty() {
-            None
-        } else {
-            Some(flips)
+        flips
+    }
+
+    /// Plays a disc at the given index for the current player, flipping opposition discs
+    /// and updating the score.
+    pub fn play(&mut self, index: usize) {
+        // find the flips for playing that position
+        let mut flips = self.flips_for(index);
+
+        // save this for scoring updates
+        let changed = flips.len();
+
+        // add the position to discs to set
+        flips.push(index);
+
+        // iterate through the flips and set those discs to the current player
+        for p in flips.into_iter() {
+            self.board.set(p, self.turn);
         }
+
+        // save the played position to the transcript
+        self.transcript.push(Play::Move(Position::new(index)));
+
+        // update the score and completeness
+        if self.turn == Disc::Dark {
+            self.dark += changed + 1; // include the newly placed piece
+            self.light -= changed; // all of the flipped discs
+        } else {
+            self.light += changed + 1; // include the newly placed piece
+            self.dark -= changed; // all of the flipped discs
+        }
+
+        self.empty -= 1;
+
+        if self.empty == 0 {
+            self.is_complete = true;
+        }
+
+        // update the turn
+        self.turn = self.turn.opposite();
+    }
+
+    /// Forfeits a turn for the current player
+    pub fn pass(&mut self) {
+        // if the last (opponent) play was also a pass, then the game is over.
+        if self.transcript.last() == Some(&Play::Pass) {
+            self.is_complete = true;
+        } else {
+            // otherwise, mark the pass and move on to the other player!
+            self.transcript.push(Play::Pass);
+            self.turn = self.turn.opposite();
+        }
+    }
+
+    fn validate_completion(&mut self) {
+        // if there are no more valid moves for either player, then the game is complete.
+        self.is_complete =
+            self.valid_moves(Disc::Dark).count() == 0 && self.valid_moves(Disc::Light).count() == 0
+    }
+
+    fn can_move(&self, player: Disc, index: usize) -> bool {
+        // basic check ... occupied?
+        if self.board.get(index).is_some() {
+            return false;
+        }
+
+        for line in self.board.lines_for(index) {
+            if self.move_from_empty(player, line).is_some() {
+                return true;
+            }
+        }
+
+        false
+    }
+
+    fn move_from_empty(&self, player: Disc, indexes: &[usize]) -> Option<usize> {
+        let mut line_started = false;
+
+        for idx in indexes {
+            // ignore the first position; it's not a target, it's where we'll be placing the piece!
+            if idx == indexes.first()? {
+                continue;
+            }
+
+            // no disc? return.
+            let disc = self.board.get(*idx)?;
+
+            // possible target disc to flip!
+            if disc == player.opposite() {
+                line_started = true;
+                continue;
+            }
+
+            // we've found our own color -- if we have targets, it's a valid move!
+            if disc == player {
+                if !line_started {
+                    return None;
+                }
+
+                return indexes.first().cloned();
+            }
+        }
+
+        None
     }
 }
 
@@ -297,23 +296,24 @@ mod tests {
 
         let mut game = Game::new();
 
-        let mut valid_indexes = game.valid_moves(game.turn);
-        let vm1 = valid_indexes.pop().unwrap();
-        game.play(vm1);
+        let valid_move1 = game.valid_moves(game.turn).next().unwrap();
+        game.play(valid_move1);
 
         assert_eq!(game.turn, Disc::Light);
-        assert_eq!(game.transcript, vec![Play::Move(Position::new(vm1))]);
+        assert_eq!(
+            game.transcript,
+            vec![Play::Move(Position::new(valid_move1))]
+        );
 
-        valid_indexes = game.valid_moves(game.turn);
-        let vm2 = valid_indexes.pop().unwrap();
-        game.play(vm2);
+        let valid_move2 = game.valid_moves(game.turn).next().unwrap();
+        game.play(valid_move2);
 
         assert_eq!(game.turn, Disc::Dark);
         assert_eq!(
             game.transcript,
             vec![
-                Play::Move(Position::new(vm1)),
-                Play::Move(Position::new(vm2))
+                Play::Move(Position::new(valid_move1)),
+                Play::Move(Position::new(valid_move2))
             ]
         );
     }
@@ -343,7 +343,8 @@ mod tests {
         let mut game = Game::new();
 
         while !game.is_complete {
-            match game.valid_moves(game.turn).pop() {
+            let vm = game.valid_moves(game.turn).next();
+            match vm {
                 None => game.pass(),
                 Some(vm) => game.play(vm),
             };
@@ -359,7 +360,8 @@ mod tests {
         let mut game = Game::new();
 
         while !game.is_complete {
-            match game.valid_moves(game.turn).pop() {
+            let vm = game.valid_moves(game.turn).next();
+            match vm {
                 None => game.pass(),
                 Some(vm) => game.play(vm),
             };
